local Aloft = Aloft
if not Aloft then return end

-----------------------------------------------------------------------------

local AloftCastBar = Aloft:NewModule("CastBar", "AceEvent-2.0")
local SML = AceLibrary("LibSharedMedia-3.0")

-----------------------------------------------------------------------------

AloftCastBar.db = Aloft:AcquireDBNamespace("castBar")
Aloft:RegisterDefaults("castBar", "profile", {
	offsets =
	{
		left		= 0,
		right		= 0,
		vertical	= -12,
	},
	border			= "None",
	borderColor		= { 1, 1, 1, 1 },
	height			= 10,
	texture			= "Blizzard",
	color			= { 1.0, 0.7, 0.0, 1.0 },
	backdropColor	= { 0.25, 0.25, 0.25, 0.5 },
})

-----------------------------------------------------------------------------

-- local AloftFrame
local profile
local inset

local defaultBackdropTable = { }
local backdropTable =
{
	tile = false, tileSize = 16,
	edgeSize = 16,
	insets = { left = 0, right = 0, top = 0, bottom = 0 }
}

-----------------------------------------------------------------------------

function AloftCastBar:UpdateAll()
	for aloftData in Aloft:IterateNameplates() do
		self:SetupFrame(aloftData)
	end

	for aloftData in Aloft:IterateVisibleNameplates() do
		self:OnCastBarShow(aloftData)
	end
end

-----------------------------------------------------------------------------

function AloftCastBar:OnInitialize()
	profile = self.db.profile
end

function AloftCastBar:OnEnable()
	-- AloftFrame = Aloft:HasModule("Frame") and Aloft:GetModule("Frame")

	self:RegisterEvent("Aloft:SetupFrame", "SetupFrame")
	self:RegisterEvent("Aloft:OnCastBarShow", "OnCastBarShow")
	self:RegisterEvent("Aloft:OnCastBarHide", "OnCastBarHide")

	self:RegisterEvent("SharedMedia_SetGlobal", function(mediatype, override)
		if mediatype == "statusbar" then
			self:UpdateAll()
		end
	end)

	self:RegisterEvent("Aloft:SetAll", function(type, value)
		if profile[type] then
			profile[type] = value
			self:UpdateAll()
		end
	end)

	self:UpdateAll()
end

function AloftCastBar:OnDisable()
	self:UnregisterAllEvents()

	defaultBackdropTable.bgFile = ""

	for aloftData in Aloft:IterateNameplates() do
		local castBar = aloftData.castBar

		castBar:ClearAllPoints()
		castBar:SetPoint("BOTTOMRIGHT", aloftData.castBarOverlayRegion, "BOTTOMRIGHT", -4.5, 4.5)
		castBar:SetWidth(116.5)
		castBar:SetHeight(10.18)
		castBar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		castBar:SetBackdrop(defaultBackdropTable)
		castBar:SetBackdropColor(0, 0, 0, 0)
		castBar:SetBackdropBorderColor(0, 0, 0, 0)
		castBar:SetFrameLevel(1)
	end
end

function AloftCastBar:GetBorder(aloftData)
	return ((profile.border ~= "None") and 4) or 0, SML:Fetch("border", profile.border)
end

function AloftCastBar:SetupFrame(aloftData)
	local castBar = aloftData.castBar

	-- ChatFrame7:AddMessage("AloftCastBar:SetupFrame(): parent " .. tostring(aloftData.name) .. "/" .. tostring(castBar:GetParent()) .. "/" .. tostring(aloftData.nameplateFrame) .. "/" .. tostring(UIParent))

	local texture = SML:Fetch("statusbar", profile.texture)
	local inset, edgeFile = self:GetBorder(aloftData)

	backdropTable.bgFile = texture
	backdropTable.edgeFile = edgeFile
	backdropTable.insets = { left = inset, right = inset, top = inset, bottom = inset }

	-- ChatFrame7:AddMessage("AloftCastBar:SetupFrame(): cast bar frame level " .. tostring(castBar:GetFrameLevel()))
	castBar:SetFrameLevel(1)
	castBar:SetStatusBarTexture(texture)

	castBar:SetBackdrop(backdropTable)
	castBar:SetBackdropColor(unpack(profile.backdropColor))
	castBar:SetBackdropBorderColor(unpack(profile.borderColor))

	-- This manipulates the castbar background to always display above the frame background
	local barRegion, backgroundRegion = castBar:GetRegions()
	barRegion:ClearAllPoints()
	barRegion:SetPoint("TOPLEFT", castBar, "TOPLEFT", inset, -inset)
	barRegion:SetPoint("BOTTOMRIGHT", castBar, "BOTTOMRIGHT", -inset, inset)
	barRegion:SetDrawLayer("ARTWORK")

	backgroundRegion:SetDrawLayer("BACKGROUND")
	backgroundRegion:Show()
end

function AloftCastBar:OnCastBarShow(aloftData)
	local castBar = aloftData.castBar
	if castBar then
		local inset, _ = self:GetBorder(aloftData)
		local layoutFrame = aloftData.layoutFrame
		if not layoutFrame then
			layoutFrame = Aloft:AcquireLayoutFrame(aloftData)
		end
		if not layoutFrame then
			ChatFrame7:AddMessage("AloftCastBar:OnCastBarShow(): no layoutFrame " .. tostring(aloftData.name))
			ChatFrame7:AddMessage("AloftCastBar:OnCastBarShow(): " .. debugstack())
		end

		castBar:SetFrameLevel(1)
		castBar:ClearAllPoints()
		castBar:SetPoint("TOPLEFT", layoutFrame, "TOPLEFT", profile.offsets.left - inset, profile.offsets.vertical + inset)
		castBar:SetPoint("BOTTOMRIGHT", layoutFrame, "TOPRIGHT", profile.offsets.right + inset, profile.offsets.vertical - profile.height - inset)
		castBar:SetAlpha(1.0)

		castBar:SetStatusBarColor(unpack(profile.color))

		self:UpdateAlpha(castBar)
		self:ScheduleRepeatingEvent("AloftCastBar:UpdateAlpha", self.UpdateAlpha, 0.1, self, aloftData.castBar)
	end
end

function AloftCastBar:OnCastBarHide(aloftData)
	self:CancelScheduledEvent("AloftCastBar:UpdateAlpha")
end

function AloftCastBar:UpdateAlpha(castBar)
	local r, g, b, a = unpack(profile.backdropColor)
	local _, _, _, castBarAlpha = castBar:GetStatusBarColor()
	a = a * castBarAlpha

	castBar:SetBackdropColor(r, g, b, a)
end

-----------------------------------------------------------------------------
