local Aloft = Aloft
if not Aloft then return end

-----------------------------------------------------------------------------

local AloftSpellIcon = Aloft:NewModule("SpellIcon", "AceEvent-2.0")

-----------------------------------------------------------------------------

AloftSpellIcon.db = Aloft:AcquireDBNamespace("spellIcon")
Aloft:RegisterDefaults("spellIcon", "profile", {
	enable			= true,
	point			= "LEFT",
	relativeToPoint	= "LEFT",
	offsetX			= 0,
	offsetY			= 0,
	size			= 11
})

-----------------------------------------------------------------------------

local profile

-----------------------------------------------------------------------------

function AloftSpellIcon:UpdateAll()
	for aloftData in Aloft:IterateNameplates() do
		if aloftData:IsTarget() then
			self:OnCastBarShow(aloftData)
		end
	end
end

-----------------------------------------------------------------------------

function AloftSpellIcon:OnInitialize()
	profile = self.db.profile
end

function AloftSpellIcon:OnEnable()
	self:RegisterEvent("Aloft:OnCastBarShow", "OnCastBarShow")
	self:UpdateAll()
end

function AloftSpellIcon:OnDisable()
	self:UnregisterAllEvents()

	for aloftData in Aloft:IterateNameplates() do
		local spellIconRegion = aloftData.spellIconRegion

		spellIconRegion:ClearAllPoints()
		spellIconRegion:SetPoint("CENTER", aloftData.nameplateFrame, "BOTTOMLEFT", 13.33, 10.29)
		spellIconRegion:SetWidth(14.5)
		spellIconRegion:SetHeight(14.5)
		spellIconRegion:SetParent(aloftData.nameplateFrame)
	end
end

-- TODO: propagate this to name text, level text, boss icon, and/or other "default" nameplate components as needed
function AloftSpellIcon:GetInset(aloftData)
	return ((profile.border ~= "None") and 4) or 0
end

function AloftSpellIcon:OnCastBarShow(aloftData)
	local spellIconRegion = aloftData.spellIconRegion
	if profile.enable then
		local castBar = aloftData.castBar

		spellIconRegion:SetParent(castBar)

		local inset = self:GetInset(aloftData)
		local hinset, vinset = self:AdjustFrame(inset, profile.relativeToPoint)
		self:PlaceFrame(aloftData.spellIconRegion, castBar, profile, hinset, vinset)
		spellIconRegion:SetDrawLayer("OVERLAY")
		-- ChatFrame7:AddMessage("AloftSpellIcon:OnCastBarShow(): " .. tostring(spellIconRegion:GetTexture()))
	else
		spellIconRegion:SetTexture("")
		spellIconRegion:SetAlpha(0)
		spellIconRegion:Hide()
	end
end

-----------------------------------------------------------------------------
